#
# spec file for package indent
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           indent
Version:        2.2.13
Release:        3.4
Summary:        Indentation of Source Code in various styles
License:        GPL-3.0-or-later
Group:          Development/Languages/C and C++
URL:            https://www.gnu.org/software/indent
Source0:        ftp://ftp.gnu.org/gnu/%{name}/%{name}-%{version}.tar.xz
Source1:        ftp://ftp.gnu.org/gnu/%{name}/%{name}-%{version}.tar.xz.sig
Source2:        https://savannah.gnu.org/people/viewgpg.php?user_id=94096#/%{name}.keyring
# PATCH-FIX-SECURITY fix-out-of-buffer-read-CVE-2023-40305.patch fix-heap-buffer-overwrite-search_brace-CVE-2023-40305 bsc#1214243 CVE-2023-40305 antonio.teixeira@suse.com -- indent: heap-based buffer overflow in search_brace() in indent.c via a crafted file
Patch0:         fix-out-of-buffer-read-CVE-2023-40305.patch
Patch1:         fix-heap-buffer-overwrite-search_brace-CVE-2023-40305.patch
# CVE-2024-0911 [bsc#1219210], heap-based buffer overflow in set_buf_break()
Patch2:         indent-CVE-2024-0911.patch
BuildRequires:  makeinfo
BuildRequires:  texi2html

%description
Indent can be used to make code easier to read. It can also convert
from one style of writing C code to another. indent understands a
substantial amount of C syntax, but it also tries to cope with
incomplete and malformed syntax.

%lang_package

%prep
%autosetup -p1

%build
%configure \
	--docdir=%{_docdir}/%{name} \
	%{nil}
%make_build

%install
%make_install
rm -f %{buildroot}%{_bindir}/texinfo2man
rm -f %{buildroot}/%{_infodir}/dir
%find_lang %{name}

%check
%make_build check

%files
%{_bindir}/*
%license COPYING
%doc NEWS ChangeLog
%{_docdir}/%{name}
%{_infodir}/%{name}.info%{?ext_info}
%{_mandir}/man1/indent.1%{?ext_man}

%files lang -f %{name}.lang
%license COPYING

%changelog
* Fri Feb 16 2024 pgajdos@suse.com
- security update
- added patches
  fix CVE-2024-0911 [bsc#1219210], heap-based buffer overflow in set_buf_break()
  + indent-CVE-2024-0911.patch
* Mon Aug 21 2023 Antonio Teixeira <antonio.teixeira@suse.com>
- Fix memory safety issues, bsc#1214243, CVE-2023-40305:
  * fix-out-of-buffer-read-CVE-2023-40305.patch
  * fix-heap-buffer-overwrite-search_brace-CVE-2023-40305.patch
* Fri Mar 24 2023 Andreas Stieger <andreas.stieger@gmx.de>
- Update to 2.2.13:
  * Fix buffer overflows and use after free bugs (boo#1209718)
  * Recognize binary integer literals
  * Updated translations, new translation: Portuguese
* Thu Feb 20 2020 Martin Pluskal <mpluskal@suse.com>
- Use xz sources
- Split lang package
- Fetch keyring from savannah
* Mon Dec 17 2018 astieger@suse.com
- indent 2.2.12:
  * New options:
    + -pal / --pointer-align-left and -par / --pointer-align-right
    + -fnc / --fix-nested-comment
    + -gts / --gettext-strings
    + -slc / --single-line-conditionals
    + -as / --align-with-spaces
    + -ut / --use-tabs
    + -nut / --no-tabs
    + -sar / --spaces-around-initializers
    + -ntac / --dont-tab-align-comments
    + -linux preset now includes -nbs.
    + -kr preset now includes -par.
  * Indent now recognises C99 and C11 keywords, and also typeof.
- drop patches:
  * indent-2.2.10-lcall.diff
  * indent-2.2.10-man.diff
  * indent-2.2.10-warnings.diff
  * indent-texi2html-5.0.patch
- add upstream signing key and verify signature
* Fri Dec 15 2017 kstreitova@suse.com
- update to 2.2.11
  * fixed Debian Bug report logs - #485764, Regression with
  - -blank-lines-after-declarations in 2.2.10
  * fail instead of removing embedded NULLs in input files
  * fixed handling of '...' range 'operator in C++ language
  * fixed -nlps option.
- remove indent-2.2.10-nothing_is_void.diff that is no longer
  needed
- remove indent-2.2.10-cdw.diff that is useless now
- refresh indent-2.2.10-warnings.diff
- re-enable parallel build
- ship COPYING NEWS README and ChangeLog files
* Thu Mar 23 2017 kstreitova@suse.com
- cleanup with spec-cleaner
- get rid of %%{name} and %%{version} macros in the patch names
* Thu Feb 19 2015 dimstar@opensuse.org
- Replace texinfo BuildRequires with makeinfo and texi2html: only
  those parts are needed.
- Add indent-texi2html-5.0.patch: Fix build with texi2html 5.0
  (note: patches Makeinfo.in in order to not depend on libtool)
- Move install_info_delete from postun to preun.
* Wed Feb 18 2015 mpluskal@suse.com
- Use url for source
- Add gpg signature
- Cleanup spec file with spec cleaner
- Remove useless configure option --with-pic
* Fri Jul 20 2012 coolo@suse.com
- texi2html is required
* Tue Aug  5 2008 prusnak@suse.cz
- updated to 2.2.10
  * added --indent-label and --linux-style options to control
    indentation of goto labels and supply a canned set of settings
    that closely matches the preferred style for the linux kernel
  * GPLv3 is used now
- removed obsoleted patches:
  * overflow.patch (included in update)
* Sun Feb 24 2008 crrodriguez@suse.de
- use find_lang macro
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Dec 13 2004 sndirsch@suse.de
- moved chinese mo file to correct directory (Bug #47262)
* Wed Sep 15 2004 aj@suse.de
- Fix compiler warnings.
* Wed Jun 30 2004 tcrhak@suse.cz
- removed texinfo2man from the file list (bug #42247)
* Fri Apr 16 2004 mmj@suse.de
- Functions that are void should be declared as such
* Thu Mar  4 2004 tcrhak@suse.cz
- security fix for overflow (bug #33790)
* Sat Jan 10 2004 adrian@suse.de
- build as user
* Wed May 14 2003 mmj@suse.de
- Remove unwanted files
* Thu Apr 24 2003 ro@suse.de
- fix install_info --delete call and move from preun to postun
* Thu Feb 13 2003 mmj@suse.de
- Add %%install_info macro [#23428]
* Mon Jan  6 2003 tcrhak@suse.cz
- update to version 2.2.9
* Sat Jul 13 2002 tcrhak@suse.cz
- update to version 2.2.8a
* Thu Oct  4 2001 schwab@suse.de
- Don't run automake/autoconf.
* Sun Dec  3 2000 smid@suse.cz
- New version 2.2.6
* Thu Feb 10 2000 kukuk@suse.de
- Update to 2.2.5
- Move /usr/{info,man} -> /usr/share/{info,man}
* Sun Oct 10 1999 kukuk@suse.de
- Update to version 2.2.3
- Use BuildRoot
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Tue Sep  7 1999 kukuk@suse.de
- Add make to build section
* Thu Aug 26 1999 kukuk@suse.de
- Update to version 2.2.0
* Mon Feb 22 1999 ro@suse.de
- dont redefine memcpy for glibc-2.1
* Thu Jan 21 1999 ro@suse.de
- no m486 on alpha
- include <string.h> in indent.c
